@@ -1,5 +1,5 @@
-/* gsasl.h --- Header file for GNU SASL Library.                      -*- c -*-
- * Copyright (C) 2002, 2003, 2004  Simon Josefsson
+/* gsasl.h --- Header file for GNU SASL Library.
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -13,9 +13,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public License
- * License along with GNU SASL Library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU Lesser General Public
+ * License License along with GNU SASL Library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -31,7 +32,14 @@ extern "C"
 {
 # endif
 
-# define GSASL_VERSION "0.2.1"
+  /**
+   * GSASL_VERSION
+   *
+   * String defined via CPP denoting the header file version number.
+   * Used together with stringprep_check_version() to verify header file
+   * and run-time library consistency.
+   */
+# define GSASL_VERSION "0.2.12"
 
   /* RFC 2222: SASL mechanisms are named by strings, from 1 to 20
    * characters in length, consisting of upper-case letters, digits,
@@ -52,20 +60,15 @@ extern "C"
     GSASL_NEEDS_MORE = 1,
     GSASL_UNKNOWN_MECHANISM = 2,
     GSASL_MECHANISM_CALLED_TOO_MANY_TIMES = 3,
-    GSASL_FOPEN_ERROR = 5,
-    GSASL_FCLOSE_ERROR = 6,
     GSASL_MALLOC_ERROR = 7,
     GSASL_BASE64_ERROR = 8,
     GSASL_CRYPTO_ERROR = 9,
-    GSASL_UNICODE_NORMALIZATION_ERROR = 28,
     GSASL_SASLPREP_ERROR = 29,
     GSASL_MECHANISM_PARSE_ERROR = 30,
     GSASL_AUTHENTICATION_ERROR = 31,
     GSASL_INTEGRITY_ERROR = 33,
-    GSASL_NO_MORE_REALMS = 34,
     GSASL_NO_CLIENT_CODE = 35,
     GSASL_NO_SERVER_CODE = 36,
-    GSASL_INVALID_HANDLE = 50,
     GSASL_NO_CALLBACK = 51,
     GSASL_NO_ANONYMOUS_TOKEN = 52,
     GSASL_NO_AUTHID = 53,
@@ -75,7 +78,6 @@ extern "C"
     GSASL_NO_PIN = 57,
     GSASL_NO_SERVICE = 58,
     GSASL_NO_HOSTNAME = 59,
-    GSASL_CANNOT_VALIDATE = 60,
     /* Mechanism specific errors. */
     GSASL_GSSAPI_RELEASE_BUFFER_ERROR = 37,
     GSASL_GSSAPI_IMPORT_NAME_ERROR = 38,
@@ -112,6 +114,12 @@ extern "C"
     GSASL_CIPHER_AES = 32
   } Gsasl_cipher;
 
+  /* SASLprep flags, see gsasl_saslprep(). */
+  typedef enum
+  {
+    GSASL_ALLOW_UNASSIGNED = 1
+  } Gsasl_saslprep_flags;
+
   /* Library handles */
   typedef struct Gsasl Gsasl;
   typedef struct Gsasl_session Gsasl_session;
@@ -130,6 +138,7 @@ extern "C"
     GSASL_PASSCODE = 8,
     GSASL_SUGGESTED_PIN = 9,
     GSASL_PIN = 10,
+    GSASL_REALM = 11,
     /* Server validation callback properties. */
     GSASL_VALIDATE_SIMPLE = 500,
     GSASL_VALIDATE_EXTERNAL = 501,
@@ -180,8 +189,9 @@ extern "C"
   /* Property handling: property.c */
   extern void gsasl_property_set (Gsasl_session * sctx, Gsasl_property prop,
 				  const char *data);
-  extern void gsasl_property_set_raw (Gsasl_session * sctx, Gsasl_property prop,
-				   const char *data, size_t len);
+  extern void gsasl_property_set_raw (Gsasl_session * sctx,
+				      Gsasl_property prop, const char *data,
+				      size_t len);
   extern const char *gsasl_property_get (Gsasl_session * sctx,
 					 Gsasl_property prop);
   extern const char *gsasl_property_fast (Gsasl_session * sctx,
@@ -220,18 +230,17 @@ extern "C"
   extern const char *gsasl_strerror (int err);
 
   /* Internationalized string processing: stringprep.c */
-  extern char *gsasl_stringprep_nfkc (const char *in, ssize_t len);
-  extern char *gsasl_stringprep_saslprep (const char *in, int *stringprep_rc);
-  extern char *gsasl_stringprep_trace (const char *in, int *stringprep_rc);
+  extern int gsasl_saslprep (const char *in, Gsasl_saslprep_flags flags,
+			     char **out, int *stringpreprc);
 
   /* Utilities: base64.c, md5pwd.c, crypto.c */
-  extern int gsasl_base64_encode (char const *src, size_t srclength,
-				  char *target, size_t targsize);
-  extern int gsasl_base64_decode (char const *src,
-				  char *target, size_t targsize);
-  extern int gsasl_md5pwd_get_password (const char *filename,
-					const char *username,
-					char *key, size_t * keylen);
+  extern int gsasl_simple_getpass (const char *filename,
+				   const char *username,
+				   char **key);
+  extern int gsasl_base64_to (const char *in, size_t inlen,
+			      char **out, size_t * outlen);
+  extern int gsasl_base64_from (const char *in, size_t inlen,
+				char **out, size_t * outlen);
   extern int gsasl_nonce (char *data, size_t datalen);
   extern int gsasl_random (char *data, size_t datalen);
   extern int gsasl_md5 (const char *in, size_t inlen, char *out[16]);
